###################################################
### chunk number 1: loadPackage
###################################################
#line 89 "HowTo-flowCore.Rnw"
library(flowCore)


###################################################
### chunk number 2: ReadFiles
###################################################
#line 210 "HowTo-flowCore.Rnw"
file.name <- system.file("extdata","0877408774.B08", package="flowCore")
x <- read.FCS(file.name, transformation=FALSE)
summary(x)


###################################################
### chunk number 3: SearchKeywords
###################################################
#line 223 "HowTo-flowCore.Rnw"
keyword(x,c("$P1E", "$P2E", "$P3E", "$P4E"))


###################################################
### chunk number 4: PrintSummary
###################################################
#line 230 "HowTo-flowCore.Rnw"
summary(read.FCS(file.name))


###################################################
### chunk number 5: PrintSummary2
###################################################
#line 239 "HowTo-flowCore.Rnw"
summary(read.FCS(file.name,transformation="scale")) 


###################################################
### chunk number 6: ReadFiles2
###################################################
#line 248 "HowTo-flowCore.Rnw"
read.FCS(file.name,alter.names=TRUE) 


###################################################
### chunk number 7: RedFiles3
###################################################
#line 258 "HowTo-flowCore.Rnw"
x <- read.FCS(file.name, column.pattern="-H") 
x 


###################################################
### chunk number 8: RedFiles3
###################################################
#line 268 "HowTo-flowCore.Rnw"
lines <- sample(100:500, 50)
y <- read.FCS(file.name, which.lines = lines) 
y 


###################################################
### chunk number 9: Plot1
###################################################
#line 284 "HowTo-flowCore.Rnw"
library(flowViz)
plot(x)


###################################################
### chunk number 10: Plot2
###################################################
#line 293 "HowTo-flowCore.Rnw"
plot(x,c("FL1-H", "FL2-H"))


###################################################
### chunk number 11: plot3
###################################################
#line 301 "HowTo-flowCore.Rnw"
plot(x, "FL1-H", breaks=256)


###################################################
### chunk number 12: Frames
###################################################
#line 323 "HowTo-flowCore.Rnw"
frames <- lapply(dir(system.file("extdata", "compdata", "data",
                                 package="flowCore"), full.names=TRUE), 
                 read.FCS)
as(frames, "flowSet")


###################################################
### chunk number 13: Frames
###################################################
#line 336 "HowTo-flowCore.Rnw"
names(frames) <- sapply(frames, keyword, "SAMPLE ID")
fs <- as(frames, "flowSet")
fs


###################################################
### chunk number 14: metaData
###################################################
#line 354 "HowTo-flowCore.Rnw"
phenoData(fs)$Filename <- fsApply(fs,keyword, "$FIL")
pData(phenoData(fs))


###################################################
### chunk number 15: ReadFlowSet
###################################################
#line 375 "HowTo-flowCore.Rnw"
read.flowSet(path = system.file("extdata", "compdata", "data", 
             package="flowCore"))


###################################################
### chunk number 16: ReadFowSet2
###################################################
#line 404 "HowTo-flowCore.Rnw"
fs <- read.flowSet(path=system.file("extdata", "compdata", "data",
                   package="flowCore"), name.keyword="SAMPLE ID",
                   phenoData=list(name="SAMPLE ID", Filename="$FIL"))
fs
pData(phenoData(fs))


###################################################
### chunk number 17: fsApply1
###################################################
#line 443 "HowTo-flowCore.Rnw"
fsApply(fs, each_col, median)


###################################################
### chunk number 18: fsApply2
###################################################
#line 449 "HowTo-flowCore.Rnw"
fsApply(fs,function(x) apply(x, 2, median), use.exprs=TRUE)


###################################################
### chunk number 19: Transfo1
###################################################
#line 472 "HowTo-flowCore.Rnw"
plot(transform(fs[[1]], `FL1-H`=log(`FL1-H`), `FL2-H`=log(`FL2-H`)), 
     c("FL1-H","FL2-H"))


###################################################
### chunk number 20: Transfo2
###################################################
#line 480 "HowTo-flowCore.Rnw"
plot(transform(fs[[1]], log.FL1.H=log(`FL1-H`), 
               log.FL2.H=log(`FL2-H`)), c("log.FL1.H", "log.FL2.H"))


###################################################
### chunk number 21: Transfo3
###################################################
#line 515 "HowTo-flowCore.Rnw"
aTrans <- truncateTransform("truncate at 1", a=1)
aTrans


###################################################
### chunk number 22: Transfo4
###################################################
#line 520 "HowTo-flowCore.Rnw"
transform(fs,`FL1-H`=aTrans(`FL1-H`))


###################################################
### chunk number 23: rectGate
###################################################
#line 558 "HowTo-flowCore.Rnw"
rectGate <- rectangleGate(filterId="Fluorescence Region", 
                          "FL1-H"=c(0, 12), "FL2-H"=c(0, 12))


###################################################
### chunk number 24: 
###################################################
#line 585 "HowTo-flowCore.Rnw"
result = filter(fs[[1]],rectGate)
result


###################################################
### chunk number 25: Summary3
###################################################
#line 596 "HowTo-flowCore.Rnw"
summary(result)
summary(result)$n
summary(result)$true
summary(result)$p


###################################################
### chunk number 26: SummarFilter
###################################################
#line 606 "HowTo-flowCore.Rnw"
summary(filter(fs[[1]], kmeansFilter("FSC-H"=c("Low", "Medium", "High"),
                                     filterId="myKMeans")))


###################################################
### chunk number 27: 
###################################################
#line 614 "HowTo-flowCore.Rnw"
filter(fs,rectGate)


###################################################
### chunk number 28: Norm2Filter
###################################################
#line 630 "HowTo-flowCore.Rnw"
morphGate <- norm2Filter("FSC-H", "SSC-H", filterId="MorphologyGate", 
                         scale=2)
smaller <- Subset(fs, morphGate)
fs[[1]]
smaller[[1]]


###################################################
### chunk number 29: Split
###################################################
#line 643 "HowTo-flowCore.Rnw"
split(smaller[[1]], kmeansFilter("FSC-H"=c("Low","Medium","High"),
                                 filterId="myKMeans"))


###################################################
### chunk number 30: Split2
###################################################
#line 650 "HowTo-flowCore.Rnw"
split(smaller, kmeansFilter("FSC-H"=c("Low", "Medium", "High"),
                            filterId="myKMeans"))


###################################################
### chunk number 31: CombineFilter
###################################################
#line 662 "HowTo-flowCore.Rnw"

rectGate & morphGate
rectGate | morphGate
!morphGate



###################################################
### chunk number 32: Summary5
###################################################
#line 676 "HowTo-flowCore.Rnw"
summary(filter(smaller[[1]],rectGate %&% morphGate))


###################################################
### chunk number 33: Transfo5
###################################################
#line 694 "HowTo-flowCore.Rnw"
tFilter <- transform("FL1-H"=log,"FL2-H"=log)
tFilter


###################################################
### chunk number 34: TectGate3
###################################################
#line 707 "HowTo-flowCore.Rnw"
rect2 <- rectangleGate(filterId="Another Rect", "FL1-H"=c(1,2), 
"FL2-H"=c(2,3)) %on% tFilter
rect2


###################################################
### chunk number 35: Plot6
###################################################
#line 718 "HowTo-flowCore.Rnw"
plot(tFilter %on% smaller[[1]],c("FL1-H","FL2-H"))


###################################################
### chunk number 36: FilterSet1
###################################################
#line 737 "HowTo-flowCore.Rnw"
fset1 = filterSet(
	rectangleGate(filterId="Fluorescence Region","FL1-H"=c(50,100),
                      "FL2-H"=c(50,100)),
	norm2Filter("FSC-H","SSC-H",filterId="Morphology Gate", scale=2),
	~ `Fluorescence Region` & `Morphology Gate`,
	~ `Fluorescence Region` | `Morphology Gate`,
	Debris ~ ! `Morphology Gate`,
	~ `Fluorescence Region` %&% `Morphology Gate`
)
fset1



###################################################
### chunk number 37: FilterSet2
###################################################
#line 813 "HowTo-flowCore.Rnw"

f = filter(fs,fset1)
f


###################################################
### chunk number 38: FilterSet3
###################################################
#line 823 "HowTo-flowCore.Rnw"

split(fs[[1]], fset1, flowSet=TRUE)



###################################################
### chunk number 39: FilterSet4
###################################################
#line 834 "HowTo-flowCore.Rnw"

split(fs[[1]],fset1,drop=TRUE,flowSet=TRUE)



###################################################
### chunk number 40: createWorkFlow
###################################################
#line 912 "HowTo-flowCore.Rnw"
data(GvHD)
wf <- workFlow(GvHD[1:5], name="myWorkflow")
wf


###################################################
### chunk number 41: views
###################################################
#line 925 "HowTo-flowCore.Rnw"
views(wf)


###################################################
### chunk number 42: addItems
###################################################
#line 943 "HowTo-flowCore.Rnw"
tf <- transformList(colnames(GvHD[[1]])[3:6], asinh, transformationId="asinh")
add(wf, tf)
wf
views(wf)


###################################################
### chunk number 43: itemName
###################################################
#line 967 "HowTo-flowCore.Rnw"
add(wf, tf, name="another asinh transform")
wf


###################################################
### chunk number 44: addGate
###################################################
#line 989 "HowTo-flowCore.Rnw"
rg <- rectangleGate("FSC-H"=c(200,400), "SSC-H"=c(250, 400),
                    filterId="rectangle")
add(wf, rg, parent="asinh")
wf


###################################################
### chunk number 45: addQuadGate
###################################################
#line 1003 "HowTo-flowCore.Rnw"
qg <- quadGate("FL1-H"=2, "FL2-H"=4)
add(wf,qg,parent="rectangle+")
wf


###################################################
### chunk number 46: plotwf eval=FALSE
###################################################
## #line 1013 "HowTo-flowCore.Rnw"
## plot(wf)


###################################################
### chunk number 47: plotwfdo
###################################################
#line 1016 "HowTo-flowCore.Rnw"
if(suppressWarnings(require(Rgraphviz))){
    plot(wf)
}else{
    plot(1,1, type="n", axes=FALSE, ann=FALSE)
    text(1,1,"Need to install Rgraphviz")
}


###################################################
### chunk number 48: getView
###################################################
#line 1032 "HowTo-flowCore.Rnw"
wf[["rectangle+"]]
wf$asinh


###################################################
### chunk number 49: getAction
###################################################
#line 1038 "HowTo-flowCore.Rnw"
wf[["action_rectangle"]]


###################################################
### chunk number 50: getData
###################################################
#line 1044 "HowTo-flowCore.Rnw"
Data(wf[["rectangle-"]])


###################################################
### chunk number 51: summaries
###################################################
#line 1052 "HowTo-flowCore.Rnw"
summary(wf[["action_rectangle"]])
summary(wf[["CD15 FITC+CD45 PE+"]])


###################################################
### chunk number 52: plotViews
###################################################
#line 1060 "HowTo-flowCore.Rnw"
densityplot(wf[["base view"]])
xyplot(`FL1-H` ~ `FL2-H`, wf[["CD15 FITC+CD45 PE+"]])


###################################################
### chunk number 53: undo
###################################################
#line 1075 "HowTo-flowCore.Rnw"
undo(wf)
wf


###################################################
### chunk number 54: RmView
###################################################
#line 1086 "HowTo-flowCore.Rnw"
Rm('rectangle-', wf)


###################################################
### chunk number 55: RmAction
###################################################
#line 1089 "HowTo-flowCore.Rnw"
Rm('asinh', wf)


